<?php

namespace Drupal\document_ocr\Plugin\document_ocr\transformer;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileSystemInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Utility\Unicode;
use Drupal\document_ocr\Plugin\TransformerBase;
use Drupal\document_ocr\Services\GoogleTranslate as GoogleTranslateService;

/**
 * Google Translate integration transformer plugin.
 *
 * @DocumentOcrTransformer(
 *   id = "google_translate",
 *   name = @Translation("Google Translate"),
 *   description = @Translation("Google Translate integration transformer."),
 *   require_credentials = true
 * )
 */
class GoogleTranslate extends TransformerBase {

  /**
   * Google Translate serivce.
   *
   * @var \Drupal\document_ocr\Services\GoogleTranslate as GoogleTranslateService
   */
  protected $googleTranslate;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, FileSystemInterface $file_system, GoogleTranslateService $google_translate) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_type_manager, $file_system);
    $this->googleTranslate = $google_translate;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($configuration, $plugin_id, $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('file_system'),
      $container->get('document_ocr.google_translate')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function requirementsAreMet() {
    return class_exists('\Google\Cloud\Translate\V3\TranslationServiceClient');
  }

  /**
   * {@inheritdoc}
   */
  public function configurationForm(array $form, FormStateInterface $form_state) {
    $this->googleTranslate->setCredentials($this->getCredentials());
    $configuration = $this->getConfiguration();
    $form['language'] = [
      '#type' => 'select',
      '#title' => $this->t('Translate to Language'),
      '#description' => $this->t('Google Translate supported languages. <a href="@link" target="_blank">Learn more</a>.', ['@link' => 'https://cloud.google.com/translate/docs/languages']),
      '#options' => $this->googleTranslate->getSupportedLanguages(),
      '#default_value' => !empty($configuration['language']) ? $configuration['language'] : '',
      '#required' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function configurationValues(array &$form, FormStateInterface $form_state) {
    return [
      'language' => $form_state->getValue('language'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function transform($value, $configuration) {
    try {
      $translated_text = [];
      $response = $this->googleTranslate
        ->setCredentials($this->getCredentials())
        ->translate($value, $configuration['language']);
      foreach ($response->getTranslations() as $translation) {
        $translated_text[] = $translation->getTranslatedText();
      }
      return join('', $translated_text);
    }
    catch (\Exception $ex) {
      return $value;
    }
  }

}
